@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from widgetastic.widget import WidgetDescriptor
 
 
@@ -48,3 +46,4 @@ def test_descriptor_on_class():
     assert hc.desc is obj
     assert obj.parent is hc
     assert hc.widget_accessed is hc.desc
+    assert hc.desc.parent_descriptor is HostClass.desc
